"use strict";

import NativeWalletPayments from "./NativeWalletPayments.js";
export { useApplePay } from "./useApplePay.js";
export { default as ApplePayButton } from "./ApplePayButton.js";

// Debit cards

// @ts-expect-error This applies the turbo module version only when turbo is enabled for backwards compatibility.
const isTurboModuleEnabled = global?.__turboModuleProxy != null;
const WalletPaymentsModule = isTurboModuleEnabled ? require('./NativeWalletPayments').default : NativeWalletPayments;

/**
 * canMakePayments
 * This function checks if the device supports Apple Pay and if the user has any cards added.
 * @returns {Promise<boolean>} - A promise that resolves with a boolean value.
 */
export function canMakePayments() {
  return WalletPaymentsModule.canMakePayments();
}

/**
 * showPaymentSheet
 * This function invokes the native Apple Pay sheet with the provided payment data.
 * @param {PaymentData} data - The payment request details including merchant info, items, and optional fields.
 * @returns {Promise<PaymentResult>} - A promise that resolves with the payment result.
 */
export function showPaymentSheet(data) {
  return WalletPaymentsModule.showPaymentSheet(data);
}

/**
 * updateShippingMethods
 * This function updates the shipping methods in the Apple Pay sheet.
 * It can be called after the application receives the shipping contact details
 * from the event listener.
 */
export function updateShippingMethods(shippingMethods) {
  WalletPaymentsModule.updateShippingMethods(shippingMethods);
}

/**
 * updateSummaryItems
 * This function updates the summary items in the Apple Pay sheet.
 * It can be called after the application receives the shipping method details
 * from the event listener.
 */
export function updateSummaryItems(summaryItems) {
  WalletPaymentsModule.updateSummaryItems(summaryItems);
}

/**
 * confirmPayment
 * This function confirms the payment with the provided status and errors and closes the Apple Pay sheet.
 * if the function is not called, the Apple Pay sheet will remain open and it will go into a timeout state (handled by Apple's internal logic).
 */
export function confirmPayment() {
  return WalletPaymentsModule.confirmPayment();
}

/**
 * rejectPayment
 * This function rejects the payment.
 */
export function rejectPayment() {
  return WalletPaymentsModule.rejectPayment();
}
//# sourceMappingURL=index.js.map